Model
=====

.. autoclass:: deepint.core.Model
   :exclude-members:
   :members:

.. autoclass:: deepint.core.ModelType
   :exclude-members:
   :members:

.. autoclass:: deepint.core.ModelMethod
   :exclude-members:
   :members:

.. autoclass:: deepint.core.model.ModelFeature
   :exclude-members:
   :members:

.. autoclass:: deepint.core.model.ModelInfo
   :exclude-members:
   :members:

.. autoclass:: deepint.core.model.ModelPredictions
   :exclude-members:
   :members: